==> haskell-tar-0.5.0.1-1-armv7h.pkg.tar.xz: usr/share/haskell/haskell-tar/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tar
version: 0.5.0.1
id: tar-0.5.0.1-a8cad643c7bf7723758e27ddef742396
key: tar_KzbcHMWdeyG0iD4huFJJiM
license: BSD3
copyright: 2007 Bjorn Bringert <bjorn@bringert.net>
           2008-2016 Duncan Coutts <duncan@community.haskell.org>
maintainer: Duncan Coutts <duncan@community.haskell.org>
synopsis: Reading, writing and manipulating ".tar" archive files.
description:
    This library is for working with \"@.tar@\" archive files. It
    can read and write a range of common variations of archive
    format including V7, POSIX USTAR and GNU formats.
    .
    It provides support for packing and unpacking portable
    archives. This makes it suitable for distribution but not
    backup because details like file ownership and exact
    permissions are not preserved.
    .
    It also provides features for random access to archive
    content using an index.
category: Codec
author: Duncan Coutts <duncan@community.haskell.org>
        Bjorn Bringert <bjorn@bringert.net>
exposed: True
exposed-modules:
    Codec.Archive.Tar Codec.Archive.Tar.Entry Codec.Archive.Tar.Check
    Codec.Archive.Tar.Index
hidden-modules: Codec.Archive.Tar.Types Codec.Archive.Tar.Read
                Codec.Archive.Tar.Write Codec.Archive.Tar.Pack
                Codec.Archive.Tar.Unpack Codec.Archive.Tar.Index.StringTable
                Codec.Archive.Tar.Index.IntTrie
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/tar-0.5.0.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/tar-0.5.0.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/tar-0.5.0.1
hs-libraries: HStar-0.5.0.1-KzbcHMWdeyG0iD4huFJJiM
depends:
    array-0.5.1.0-a4b4f31b03b7779670557ea46745a386
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    deepseq-1.4.1.1-3975618f889b45239daa47b7443eaeee
    directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
    filepath-1.4.0.0-73e0bec80594160bf6dd6cb25217c6bf
    time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
haddock-interfaces: /usr/share/doc/haskell-tar/html/tar.haddock
haddock-html: /usr/share/doc/haskell-tar/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tar-0.5.0.3-1-armv7h.pkg.tar.xz: usr/share/haskell/haskell-tar/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tar
version: 0.5.0.3
id: tar-0.5.0.3-0a1915ca475d218d70c2c2cc2299db4e
key: tar_4d25HkcDZy4Kthl6FBdK0c
license: BSD3
copyright: 2007 Bjorn Bringert <bjorn@bringert.net>
           2008-2016 Duncan Coutts <duncan@community.haskell.org>
maintainer: Duncan Coutts <duncan@community.haskell.org>
synopsis: Reading, writing and manipulating ".tar" archive files.
description:
    This library is for working with \"@.tar@\" archive files. It
    can read and write a range of common variations of archive
    format including V7, POSIX USTAR and GNU formats.
    .
    It provides support for packing and unpacking portable
    archives. This makes it suitable for distribution but not
    backup because details like file ownership and exact
    permissions are not preserved.
    .
    It also provides features for random access to archive
    content using an index.
category: Codec
author: Duncan Coutts <duncan@community.haskell.org>
        Bjorn Bringert <bjorn@bringert.net>
exposed: True
exposed-modules:
    Codec.Archive.Tar Codec.Archive.Tar.Entry Codec.Archive.Tar.Check
    Codec.Archive.Tar.Index
hidden-modules: Codec.Archive.Tar.Types Codec.Archive.Tar.Read
                Codec.Archive.Tar.Write Codec.Archive.Tar.Pack
                Codec.Archive.Tar.Unpack Codec.Archive.Tar.Index.StringTable
                Codec.Archive.Tar.Index.IntTrie
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/tar-0.5.0.3
library-dirs: /usr/lib/ghc-7.10.3/site-local/tar-0.5.0.3
data-dir: /usr/share/arm-linux-ghc-7.10.3/tar-0.5.0.3
hs-libraries: HStar-0.5.0.3-4d25HkcDZy4Kthl6FBdK0c
depends:
    array-0.5.1.0-a4b4f31b03b7779670557ea46745a386
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    deepseq-1.4.1.1-3975618f889b45239daa47b7443eaeee
    directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
    filepath-1.4.0.0-73e0bec80594160bf6dd6cb25217c6bf
    time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
haddock-interfaces: /usr/share/doc/haskell-tar/html/tar.haddock
haddock-html: /usr/share/doc/haskell-tar/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
